Tramo is a particular regarima model estimation algorithm, mainly used to linearized the series before performing a decomposition with Seats
Arguments
- y
the dependent variable (a
tsobject).- order, seasonal
the orders of the ARIMA model.
- mean
Boolean to include or not the mean.
- X
user defined regressors (other than calendar).
- X.td
calendar regressors.
- ao, ls, so, tc
Boolean to indicate which type of outliers should be detected.
- cv
numeric. The entered critical value for the outliers' detection procedure. If equal to 0 the critical value for the outliers' detection procedure is automatically determined by the number of observations.- ml
Use of maximum likelihood (otherwise approximation by means of Hannan-Rissanen).
- clean
Clean missing values at the beginning/end of the series. Regression variables are automatically resized, if need be.
Examples
if (FALSE) { # current_java_version >= minimal_java_version
tramo_outliers(rjd3toolkit::ABS$X0.2.09.10.M)
}